==> wordpress_0.7.0.tar.gz: wordpress-0.7.0/src/addpostview.h <==
#ifndef ADDPOSTVIEW_H
#define ADDPOSTVIEW_H

#include <QFrame>
#include <QStringList>
#include <QTimer>
#include "ui_addpostview.h"
#include "wpcustomviewbasicdata.h"
#include "WPData.h"
#include "LocationFinder.h"
#include "DialogController.h"

class BlogView;

using QtMobility::QGeoPositionInfo;

class AddPostView : public QFrame, public WPCustomViewBasicData
{
    Q_OBJECT

public:
    AddPostView(BlogView *parent = 0);
    ~AddPostView();
    void NewPost(WPDataBlog *aBlog);
    void EditPost(WPDataBlog *aBlog, WPPost aPost);
    void SelectCategories(const QStringList* aCategories);

signals:
    void ShowErrorNote(const QString& aError);

public slots:
    void SavePost();
    void ImagesAdded(const QStringList& aFilenames);
    void AddPhotosClicked(bool aDummy);
    void AddLocationDataBoxClicked(int newState);
    void AddLocationButtonPressed();
    void LocationSearchComplete(const QGeoPositionInfo& info);
    void setFocus();
    void LocationSearchCancelled();
    void LocationSearchTimedOut();

private:
    void ShowSelectedCategories();
    void keyReleaseEvent ( QKeyEvent * event  );

private slots:
    void CategoriesClicked();
    void Cancel();
    
private:
    Ui::AddPostView ui;
    BlogView* iParent;

    int iCategoryListLength;
    QStringList iCategories;

    WPDataBlog* iDataBlog;
    WPPost iPost;

    QStringList iAddedImages;

    QGeoPositionInfo iLocation;
    LocationFinder iLocationFinder;
    
    DialogController* iDialogController;
};

#endif // ADDPOSTVIEW_H

==> wordpress_0.7.1.tar.gz: wordpress-0.7.1/src/addpostview.h <==
#ifndef ADDPOSTVIEW_H
#define ADDPOSTVIEW_H

#include <QFrame>
#include <QStringList>
#include <QTimer>
#include "ui_addpostview.h"
#include "wpcustomviewbasicdata.h"
#include "WPData.h"
#include "LocationFinder.h"
#include "DialogController.h"

class BlogView;

class AddPostView : public QFrame, public WPCustomViewBasicData
{
    Q_OBJECT

public:
    AddPostView(BlogView *parent = 0);
    ~AddPostView();
    void NewPost(WPDataBlog *aBlog);
    void EditPost(WPDataBlog *aBlog, WPPost aPost);
    void SelectCategories(const QStringList* aCategories);

signals:
    void ShowErrorNote(const QString& aError);

public slots:
    void SavePost();
    void ImagesAdded(const QStringList& aFilenames);
    void AddPhotosClicked(bool aDummy);
    void AddLocationDataBoxClicked(int newState);
    void AddLocationButtonPressed();
    void LocationSearchComplete(const QtMobility::QGeoPositionInfo& info);
    void setFocus();
    void LocationSearchCancelled();
    void LocationSearchTimedOut();

private:
    void ShowSelectedCategories();
    void keyReleaseEvent ( QKeyEvent * event  );

private slots:
    void CategoriesClicked();
    void Cancel();
    
private:
    Ui::AddPostView ui;
    BlogView* iParent;

    int iCategoryListLength;
    QStringList iCategories;

    WPDataBlog* iDataBlog;
    WPPost iPost;

    QStringList iAddedImages;

#if defined(HAVE_QTM_LOCATION)
    QtMobility::QGeoPositionInfo iLocation;
#endif // defined(HAVE_QTM_LOCATION)
    LocationFinder iLocationFinder;
    
    DialogController* iDialogController;
};

#endif // ADDPOSTVIEW_H
